# Baseten

This is the Python client for [Baseten](https://baseten.co) and [Blueprint](https://blueprint.baseten.co).

## Installation

Install the latest version of the `baseten` package:

```sh
pip install --upgrade baseten
```

## Baseten

Baseten is a hosted platform for building ML-powered applications. Build apps with auto-scaling, GPU access, CRON jobs, and serverless functions.

Visit our official documentation for Baseten at [docs.baseten.co](https://docs.baseten.co).

## Blueprint

Blueprint is the model fine-tuning and serving infrastructure for developers. It's powered by Baseten infrastructure and uses the baseten PyPi package.

Visit our official documentation for Blueprint at [docs.blueprint.baseten.co](https://docs.blueprint.baseten.co).